==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/3d/3d930ce525b7b49d42d86492748e22bf.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/app/less/components/globalsearch.less */
class __TwigTemplate_b4454fc2fccebd464bd0788a90912273 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield ".gsearch--toolbar {
    border: 2px solid var(--interactive);
    overflow: hidden;
    box-shadow: rgb(from var(--background-brand) r g b / 25%) 0px 20px 20px -20px, rgb(0 0 0 / 30%) 0px 20px 60px -30px, rgb(from var(--background-brand) r g b / 35%) 0px -2px 6px 0px inset;
    border-radius: var(--border-radius-md);
    outline: 3px solid rgb(from var(--background-brand) r g b / 35%);
}

.gsearch--field {
    display: flex;
    align-items: center;
    gap: 3px;
}
.gsearch--search-magnifier {
    color: var(--interactive);
}
.gsearch--field-addon__icon {}
.gsearch--field__input {
    background-color: transparent;
    &:focus { outline-color: transparent; }
    &:hover { background-color: transparent; }
}

.gsearch--field-addon {}

.gsearch--interaction-helper {
    background-color: var(--primary-20);
}
.gsearch--interaction-navigate {}
.gsearch--interaction-close {}

.gsearch--results {
    overflow: hidden;
    box-shadow: rgb(100 100 111 / 24%) 0px 7px 20px 0px;
    border-radius: var(--border-radius-md);
}

.gsearch--results-scroll {
    max-height: 70vh;

    &:has(.content-overlay) { max-height: 55px; }
}

.gsearch--results-common__icon {
    padding: 6px;
    background-color: var(--layer);
    border-radius: 4px;
    border: 1px solid var(--border-subtle);
    vertical-align: -1px;
}

.gsearch--results-profile__img {
    --gsearch--profile__img-width: 36px;
    width: var(--gsearch--profile__img-width);
    aspect-ratio: 1/1;
    border-radius: var(--gsearch--profile__img-width);
}

.gsearch--results-profile__img--sm {
    --gsearch--profile__img-width: 26px;
}

.gsearch--results-item {
    border: 0;
    border-radius: var(--border-radius-sm);
    padding: 6px 12px;

    &,
    a { color: var(--text-secondary); }

    &:hover,
    a:hover { color: var(--text-primary); }
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/app/less/components/globalsearch.less";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/app/less/components/globalsearch.less", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/css/app/less/components/globalsearch.less");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/3d/3d930ce525b7b49d42d86492748e22bf.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/app/less/components/globalsearch.less */
class __TwigTemplate_b4454fc2fccebd464bd0788a90912273 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield ".gsearch--toolbar {
    border: 2px solid var(--interactive);
    overflow: hidden;
    box-shadow: rgb(from var(--background-brand) r g b / 25%) 0px 20px 20px -20px, rgb(0 0 0 / 30%) 0px 20px 60px -30px, rgb(from var(--background-brand) r g b / 35%) 0px -2px 6px 0px inset;
    border-radius: var(--border-radius-md);
    outline: 3px solid rgb(from var(--background-brand) r g b / 35%);
}

.gsearch--field {
    display: flex;
    align-items: center;
    gap: 3px;
}
.gsearch--search-magnifier {
    color: var(--interactive);
}
.gsearch--field-addon__icon {}
.gsearch--field__input {
    background-color: transparent;
    &:focus { outline-color: transparent; }
    &:hover { background-color: transparent; }
}

.gsearch--field-addon {}

.gsearch--interaction-helper {
    background-color: var(--primary-20);
}
.gsearch--interaction-navigate {}
.gsearch--interaction-close {}

.gsearch--results {
    overflow: hidden;
    box-shadow: rgb(100 100 111 / 24%) 0px 7px 20px 0px;
    border-radius: var(--border-radius-md);
}

.gsearch--results-scroll {
    max-height: 70vh;

    &:has(.content-overlay) { max-height: 55px; }
}

.gsearch--results-common__icon {
    padding: 6px;
    background-color: var(--layer);
    border-radius: 4px;
    border: 1px solid var(--border-subtle);
    vertical-align: -1px;
}

.gsearch--results-profile__img {
    --gsearch--profile__img-width: 36px;
    width: var(--gsearch--profile__img-width);
    aspect-ratio: 1/1;
    border-radius: var(--gsearch--profile__img-width);
}

.gsearch--results-profile__img--sm {
    --gsearch--profile__img-width: 26px;
}

.gsearch--results-item {
    border: 0;
    border-radius: var(--border-radius-sm);
    padding: 6px 12px;

    &,
    a { color: var(--text-secondary); }

    &:hover,
    a:hover { color: var(--text-primary); }
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/app/less/components/globalsearch.less";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/app/less/components/globalsearch.less", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/css/app/less/components/globalsearch.less");
    }
}
